@@ -17,34 +17,31 @@
  * Author: Dario Di Nucci <linkin88mail@gmail.com>
  */
 
-const Champlain = imports.gi.Champlain;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const Gdk = imports.gi.Gdk;
-const Hdy = imports.gi.Handy;
+import Adw from 'gi://Adw';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import Gdk from 'gi://Gdk';
+import Shumate from 'gi://Shumate';
 
-const Application = imports.application;
-const MapSource = imports.mapSource;
-const MapView = imports.mapView;
-const Service = imports.service;
-const ShapeLayer = imports.shapeLayer;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import * as MapSource from './mapSource.js';
+import {MapView} from './mapView.js';
+import * as Service from './service.js';
+import {ShapeLayer} from './shapeLayer.js';
+import * as Utils from './utils.js';
 
 const PREVIEW_WIDTH = 230;
 const PREVIEW_HEIGHT = 80;
 
-var ShapeLayerRow = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/shape-layer-row.ui',
-    Children: ['closeButton'],
-    InternalChildren: ['layerLabel', 'visibleButton']
-}, class ShapeLayerRow extends Gtk.ListBoxRow {
+export class ShapeLayerRow extends Gtk.ListBoxRow {
 
-    _init(params) {
-        this.shapeLayer = params.shapeLayer;
+    constructor(params) {
+        let shapeLayer = params.shapeLayer;
         delete params.shapeLayer;
 
-        super._init(params);
+        super(params);
 
+        this.shapeLayer = shapeLayer;
         this._layerLabel.label = this.shapeLayer.getName();
         this._layerLabel.tooltip_text = this.shapeLayer.file.get_parse_name();
         this._visibleButton.connect('clicked', () => {
@@ -58,31 +55,23 @@ var ShapeLayerRow = GObject.registerClass({
                 image.icon_name = 'layer-not-visible-symbolic';
         });
     }
-});
+}
 
-var LayersPopover = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/layers-popover.ui',
-    InternalChildren: [ 'streetLayerButton',
-                        'aerialLayerButton',
-                        'streetLayerImage',
-                        'aerialLayerImage',
-                        'hybridAerialRevealer',
-                        'layersListBox',
-                        'loadLayerButton' ]
-}, class LayersPopover extends Gtk.Popover {
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/shape-layer-row.ui',
+    Children: ['closeButton'],
+    InternalChildren: ['layerLabel', 'visibleButton']
+}, ShapeLayerRow);
+
+export class LayersPopover extends Gtk.PopoverMenu {
+
+    constructor(params) {
+        super({ width_request: 200,
+                visible: false });
 
-    _init(params) {
         this._mapView = params.mapView;
-        delete params.mapView;
 
-        super._init({ width_request: 200,
-                      no_show_all: true,
-                      transitions_enabled: false,
-                      visible: false });
-
-        this._aerialLayerButton.join_group(this._streetLayerButton);
-
-        this.get_style_context().add_class('maps-popover');
+        //this._aerialLayerButton.join_group(this._streetLayerButton);
 
         this._layersListBox.bind_model(this._mapView.shapeLayerStore,
                                        this._listBoxCreateWidget.bind(this));
@@ -90,11 +79,13 @@ var LayersPopover = GObject.registerClass({
             this._mapView.gotoBBox(row.shapeLayer.bbox);
         });
 
-        this._layersListBox.set_header_func((row, before) => {
-            let header = before ? new Gtk.Separator() : null;
-            row.set_header(header);
+        this._layersSectionBox.visible = this._mapView.shapeLayerStore.n_items > 0;
+        this._mapView.shapeLayerStore.connect('items-changed', (model) => {
+            this._layersSectionBox.visible = model.n_items > 0;
         });
 
+        // for now let's disable the map type swithery, as we only have street
+        /*
         this._layerPreviews = {
             street: {
                 source: MapSource.createStreetSource(),
@@ -103,13 +94,6 @@ var LayersPopover = GObject.registerClass({
             }
         };
 
-        if (Service.getService().tiles.streetDark) {
-            this._layerPreviews.streetDark = {
-                source: MapSource.createStreetDarkSource(),
-                widget: this._streetLayerImage,
-                lastLocation: { x: -1, y: -1, z: -1 }
-            };
-        }
         if (Service.getService().tiles.aerial) {
             this._layerPreviews.aerial = {
                 source: MapSource.createAerialSource(),
@@ -117,13 +101,6 @@ var LayersPopover = GObject.registerClass({
                 lastLocation: { x: -1, y: -1, z: -1 }
             };
         }
-        if (Service.getService().tiles.hybridAerial) {
-            this._layerPreviews.hybridAerial = {
-                source: MapSource.createHybridAerialSource(),
-                widget: this._aerialLayerImage,
-                lastLocation: { x: -1, y: -1, z: -1 }
-            };
-        }
 
         // disable the map type switch buttons if aerial is unavailable
         if (Service.getService().tiles.aerial) {
@@ -145,11 +122,6 @@ var LayersPopover = GObject.registerClass({
                                        this._setLayerPreviews.bind(this));
             this._mapView.view.connect("notify::longitude",
                                        this._setLayerPreviews.bind(this));
-            Hdy.StyleManager.get_default().connect("notify::dark",
-                                                    this._onDarkChanged.bind(this));
-            Application.settings.connect("changed::hybrid-aerial",
-                                         this._onHybridAerialChanged.bind(this));
-
         } else {
             this._streetLayerButton.visible = false;
             this._aerialLayerButton.visible = false;
@@ -159,39 +131,13 @@ var LayersPopover = GObject.registerClass({
         this._mapView.connect("map-type-changed", (_mapView, type) => {
             this.setMapType(type);
         });
+        */
     }
 
-    _onDarkChanged() {
-        if (Service.getService().tiles.streetDark &&
-            Hdy.StyleManager.get_default().dark) {
-            this._setLayerPreviewImage('streetDark', true);
-        } else {
-            this._setLayerPreviewImage('street', true);
-        }
-    }
-
-    _onHybridAerialChanged() {
-        if (Service.getService().tiles.hybridAerial &&
-            Application.settings.get('hybrid-aerial')) {
-            this._setLayerPreviewImage('hybridAerial', true);
-        } else {
-            this._setLayerPreviewImage('aerial', true);
-        }
-    }
-
+    /*
     _setLayerPreviews() {
-        if (Service.getService().tiles.streetDark &&
-            Hdy.StyleManager.get_default().dark) {
-            this._setLayerPreviewImage('streetDark');
-        } else {
-            this._setLayerPreviewImage('street');
-        }
-        if (Service.getService().tiles.hybridAerial &&
-            Application.settings.get('hybrid-aerial')) {
-            this._setLayerPreviewImage('hybridAerial');
-        } else {
-            this._setLayerPreviewImage('aerial');
-        }
+        this._setLayerPreviewImage('street');
+        this._setLayerPreviewImage('aerial');
     }
 
     _setLayerPreviewImage(layer, forceUpdate = false) {
@@ -243,17 +189,20 @@ var LayersPopover = GObject.registerClass({
     setMapType(mapType) {
         if (mapType === MapView.MapType.STREET) {
             this._streetLayerButton.active = true;
-            this._hybridAerialRevealer.reveal_child = false;
         } else if (mapType === MapView.MapType.AERIAL) {
             this._aerialLayerButton.active = true;
-            if (Service.getService().tiles.hybridAerial)
-                this._hybridAerialRevealer.reveal_child = true;
         }
     }
+    */
 
     _onRemoveClicked(row) {
         this._mapView.removeShapeLayer(row.shapeLayer);
-        if (this._layersListBox.get_children().length <= 0)
+        let numLayers = 0;
+
+        for (let layer of this._layersListBox) {
+            numLayers++;
+        }
+        if (numLayers <= 0)
             this._layersListBox.hide();
     }
 
@@ -261,7 +210,16 @@ var LayersPopover = GObject.registerClass({
         let row = new ShapeLayerRow({ shapeLayer: shapeLayer });
         row.closeButton.connect('clicked',
                                 () => this._onRemoveClicked(row));
-        this._layersListBox.show();
         return row;
     }
-});
+}
+
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/layers-popover.ui',
+    InternalChildren: [ /*'streetLayerButton',
+                        'aerialLayerButton',
+                        'streetLayerImage',
+                        'aerialLayerImage',*/
+                        'layersSectionBox',
+                        'layersListBox' ]
+}, LayersPopover);
