@@ -20,44 +20,43 @@
  *         Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  */
 
-const _ = imports.gettext.gettext;
+import gettext from 'gettext';
 
-const Champlain = imports.gi.Champlain;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gdk = imports.gi.Gdk;
-const Gio = imports.gi.Gio;
-const Gtk = imports.gi.Gtk;
-const Mainloop = imports.mainloop;
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gdk from 'gi://Gdk';
+import Gio from 'gi://Gio';
+import Gtk from 'gi://Gtk';
+import Adw from 'gi://Adw';
+import Shumate from 'gi://Shumate';
 
-const Application = imports.application;
-const ContextMenu = imports.contextMenu;
-const ExportViewDialog = imports.exportViewDialog;
-const FavoritesPopover = imports.favoritesPopover;
-const Geoclue = imports.geoclue;
-const GeocodeFactory = imports.geocode;
-const HeaderBar = imports.headerBar;
-const LocationServiceDialog = imports.locationServiceDialog;
-const MapView = imports.mapView;
-const PlaceBar = imports.placeBar;
-const PlaceEntry = imports.placeEntry;
-const PlaceStore = imports.placeStore;
-const PrintOperation = imports.printOperation;
-const Service = imports.service;
-const ShapeLayer = imports.shapeLayer;
-const Sidebar = imports.sidebar;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import {ExportViewDialog} from './exportViewDialog.js';
+import {FavoritesPopover} from './favoritesPopover.js';
+import * as Geoclue from './geoclue.js';
+import * as GeocodeFactory from './geocode.js';
+import {HeaderBarLeft, HeaderBarRight} from './headerBar.js';
+import {LocationServiceDialog} from './locationServiceDialog.js';
+import {MapView} from './mapView.js';
+import {PlaceBar} from './placeBar.js';
+import {PlaceEntry} from './placeEntry.js';
+import {PlaceStore} from './placeStore.js';
+import {PrintOperation} from './printOperation.js';
+import * as Service from './service.js';
+import {ShapeLayer} from './shapeLayer.js';
+import {Sidebar} from './sidebar.js';
+import * as Utils from './utils.js';
+
+const _ = gettext.gettext;
 
 const _CONFIGURE_ID_TIMEOUT = 100; // msecs
 const _ADAPTIVE_VIEW_WIDTH = 700;
 const _PLACE_ENTRY_MARGIN = 35;
 
-var ShapeLayerFileChooser = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/shape-layer-file-chooser.ui'
-}, class ShapeLayerFileChooser extends Gtk.FileChooserNative {
+class ShapeLayerFileChooser extends Gtk.FileChooserNative {
 
-    _init(params) {
-        super._init(params);
+    constructor(params) {
+        super(params);
         let allFilter = new Gtk.FileFilter();
         allFilter.set_name(_("All Layer Files"));
         this.add_filter(allFilter);
@@ -75,19 +74,13 @@ var ShapeLayerFileChooser = GObject.registerClass({
             this.add_filter(filter);
         });
     }
-});
+}
 
-var MainWindow = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/main-window.ui',
-    InternalChildren: [ 'headerBar',
-                        'grid',
-                        'mainStack',
-                        'mainGrid',
-                        'noNetworkView',
-                        'actionBar',
-                        'actionBarRevealer',
-                        'placeBarContainer']
-}, class MainWindow extends Gtk.ApplicationWindow {
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/shape-layer-file-chooser.ui'
+}, ShapeLayerFileChooser);
+
+export class MainWindow extends Gtk.ApplicationWindow {
 
     get mapView() {
         return this._mapView;
@@ -97,25 +90,28 @@ var MainWindow = GObject.registerClass({
         return this._placeEntry;
     }
 
-    _init(params) {
-        super._init(params);
+    get sidebar() {
+        return this._sidebar;
+    }
+
+    constructor(params) {
+        super(params);
 
         this._configureId = 0;
 
-        this._mapView = new MapView.MapView({
+        this._mapView = new MapView({
             mapType: this.application.local_tile_path ?
                 MapView.MapType.LOCAL : undefined,
-            mainWindow: this });
+            mainWindow: this,
+            hexpand: true,
+            vexpand: true });
 
-        this._mainGrid.attach(this._mapView, 0, 0, 1, 1);
+        this._grid.attach(this._mapView, 0, 0, 1, 1);
 
         this._mapView.gotoUserLocation(false);
 
         this._sidebar = this._createSidebar();
 
-        this._contextMenu = new ContextMenu.ContextMenu({ mapView: this._mapView,
-                                                          mainWindow: this });
-
         if (pkg.name.endsWith('.Devel'))
             this.get_style_context().add_class('devel');
 
@@ -128,8 +124,6 @@ var MainWindow = GObject.registerClass({
 
         this._grid.attach(this._sidebar, 1, 0, 1, 2);
 
-        this._grid.show_all();
-
         /* for some reason, setting the title of the window through the .ui
          * template does not work anymore (maybe has something to do with
          * setting a custom title on the headerbar). Setting it programmatically
@@ -140,14 +134,12 @@ var MainWindow = GObject.registerClass({
     }
 
     _createPlaceEntry() {
-        let placeEntry = new PlaceEntry.PlaceEntry({ mapView: this._mapView,
-                                                     visible: true,
-                                                     margin_start: _PLACE_ENTRY_MARGIN,
-                                                     margin_end: _PLACE_ENTRY_MARGIN,
-                                                     max_width_chars: 50,
-                                                     loupe: true,
-                                                     matchRoute: true
-                                                   });
+        let placeEntry = new PlaceEntry({ mapView: this._mapView,
+                                          visible: true,
+                                          margin_start: _PLACE_ENTRY_MARGIN,
+                                          margin_end: _PLACE_ENTRY_MARGIN,
+                                          max_width_chars: 50,
+                                          matchRoute: true });
         placeEntry.connect('notify::place', () => {
             if (placeEntry.place) {
                 this._mapView.showPlace(placeEntry.place, true);
@@ -156,24 +148,24 @@ var MainWindow = GObject.registerClass({
 
         let popover = placeEntry.popover;
         popover.connect('selected', () => this._mapView.grab_focus());
-        this._mapView.view.connect('button-press-event', () => popover.hide());
+
+        this._buttonPressGesture = new Gtk.GestureSingle();
+        this._mapView.add_controller(this._buttonPressGesture);
+        this._buttonPressGesture.connect('begin', () => popover.popdown());
         return placeEntry;
     }
 
     _createSidebar() {
-        let sidebar = new Sidebar.Sidebar(this._mapView);
+        let sidebar = new Sidebar(this._mapView);
 
         Application.routeQuery.connect('notify', () => this._setRevealSidebar(true));
-        this.application.bind_property('connected',
-                                       sidebar, 'visible',
-                                       GObject.BindingFlags.DEFAULT);
+
         return sidebar;
     }
 
     _initPlaceBar() {
-        this._placeBar = new PlaceBar.PlaceBar({ mapView: this._mapView,
-                                                 visible: true });
-        this._placeBarContainer.add(this._placeBar);
+        this._placeBar = new PlaceBar({ mapView: this._mapView, mainWindow: this });
+        this._placeBarContainer.append(this._placeBar);
 
         this.application.bind_property('selected-place',
                                        this._placeBar, 'place',
@@ -181,20 +173,11 @@ var MainWindow = GObject.registerClass({
     }
 
     _initDND() {
-        this.drag_dest_set(Gtk.DestDefaults.DROP, null, 0);
-        this.drag_dest_add_uri_targets();
+        this._dropTarget = Gtk.DropTarget.new(Gio.File, Gdk.DragAction.COPY);
+        this.add_controller(this._dropTarget);
 
-        this.connect('drag-motion', (widget, ctx, x, y, time) => {
-            Gdk.drag_status(ctx, Gdk.DragAction.COPY, time);
-            return true;
-        });
-
-        this.connect('drag-data-received', (widget, ctx, x, y, data, info, time) => {
-            let files = data.get_uris().map(Gio.file_new_for_uri);
-            if (this._mapView.openShapeLayers(files))
-                Gtk.drag_finish(ctx, true, false, time);
-            else
-                Gtk.drag_finish(ctx, false, false, time);
+        this._dropTarget.connect('drop', (target, value, x, y, data) => {
+            return this._mapView.openShapeLayers([value]);
         });
     }
 
@@ -207,10 +190,6 @@ var MainWindow = GObject.registerClass({
                 state: ['b', false],
                 onActivate: () => this._onMapTypeMenuActivate()
             },
-            'hybrid-aerial': {
-                paramType:     'b',
-                setting:       'hybrid-aerial'
-            },
             'goto-user-location': {
                 accels: ['<Primary>L'],
                 onActivate: () => this._onGotoUserLocationActivate()
@@ -226,15 +205,16 @@ var MainWindow = GObject.registerClass({
             },
             'zoom-in': {
                 accels: ['plus', '<Primary>plus', 'KP_Add', '<Primary>KP_Add', 'equal', '<Primary>equal'],
-                onActivate: () => this._mapView.view.zoom_in()
+                onActivate: () => this._mapView.zoomIn()
             },
             'zoom-out': {
                 accels: ['minus', '<Primary>minus', 'KP_Subtract', '<Primary>KP_Subtract'],
-                onActivate:  () => this._mapView.view.zoom_out()
+                onActivate:  () => this._mapView.zoomOut()
             },
-            'toggle-scale': {
+            'show-scale': {
                 accels: ['<Primary>S'],
-                onActivate:  () => this._mapView.toggleScale()
+                paramType: 'b',
+                setting: 'show-scale'
             },
             'find': {
                 accels: ['<Primary>F'],
@@ -248,9 +228,13 @@ var MainWindow = GObject.registerClass({
                 accels: ['<Primary>O'],
                 onActivate: () => this._onOpenShapeLayer()
             },
+            'show-main-menu': {
+                accels: ['F10'],
+                onActivate: () => this._showMainMenu()
+            },
             'export-as-image': {
                 onActivate: () => this._onExportActivated()
-            }
+            },
         };
 
         // when aerial tiles are available, add shortcuts to switch
@@ -270,74 +254,38 @@ var MainWindow = GObject.registerClass({
     }
 
     _initSignals() {
-        this.connect('delete-event', this._quit.bind(this));
-        this.connect('configure-event',
-                     this._onConfigureEvent.bind(this));
+        this.connect('close-request', () => this._quit());
+        this.connect('notify::default-width', () => this._onSizeChanged());
+        this.connect('notify::default-height', () => this._onSizeChanged());
 
-        this.connect('window-state-event',
-                     this._onWindowStateEvent.bind(this));
+        this.connect('notify::maximized', () => this._onMaximizedChanged());
+        // TODO: GTK4, is this needed?
+        /*
         this._mapView.view.connect('button-press-event', () => {
             // Can not call something that will generate clutter events
             // from a clutter event-handler. So use an idle.
-            Mainloop.idle_add(() => this._mapView.grab_focus());
+            GLib.idle_add(null, () => this._mapView.grab_focus());
         });
+        */
 
-        this.application.connect('notify::connected', () => {
-            if (this.application.connected || this.application.local_tile_path)
-                this._mainStack.visible_child = this._mainGrid;
-            else
-                this._mainStack.visible_child = this._noNetworkView;
-        });
+        //this._placeEntry.set_key_capture_widget(this)
 
-        /*
-         * If the currently focused widget is an entry then we will
-         * hijack the key-press to the main window and make sure that
-         * they reach the entry before they can be swallowed as accelerator.
-         */
-        /* TODO: GTK 4. This should probably be handled by something like
-         * setting the map view as key capture widget for the search entry
-         */
-        this.connect('key-press-event', (window, event) => {
-            let focusWidget = window.get_focus();
-            let keyval = event.get_keyval()[1];
-            let keys = [Gdk.KEY_plus, Gdk.KEY_KP_Add,
-                        Gdk.KEY_minus, Gdk.KEY_KP_Subtract,
-                        Gdk.KEY_equal];
-            let isPassThroughKey = keys.indexOf(keyval) !== -1;
+        let viewport = this._mapView.map.viewport;
 
-            /* if no entry is focused, and the key is not one we should treat
-             * as a zoom accelerator when no entry is focused, focus the
-             * main search entry in the headebar to propaget the keypress there
-             */
-            if (!(focusWidget instanceof Gtk.Entry) && !isPassThroughKey) {
-                /* if the search entry does not handle the event, pass it on
-                 * instead of activating the entry
-                 */
-                if (this._placeEntry.handle_event(event) === Gdk.EVENT_PROPAGATE)
-                    return false;
+        viewport.connect('notify::zoom-level',
+                         this._updateZoomButtonsSensitivity.bind(this));
+        viewport.connect('notify::max-zoom-level',
+                         this._updateZoomButtonsSensitivity.bind(this));
+        viewport.connect('notify::min-zoom-level',
+                         this._updateZoomButtonsSensitivity.bind(this));
 
-                this._placeEntry.has_focus = true;
-                focusWidget = this._placeEntry;
-            }
-
-            if (focusWidget instanceof Gtk.Entry)
-                return focusWidget.event(event);
-
-            return false;
-        });
-
-        this._mapView.view.connect('notify::zoom-level',
-                                   this._updateZoomButtonsSensitivity.bind(this));
-        this._mapView.view.connect('notify::max-zoom-level',
-                                   this._updateZoomButtonsSensitivity.bind(this));
-        this._mapView.view.connect('notify::min-zoom-level',
-                                   this._updateZoomButtonsSensitivity.bind(this));
+        this._updateZoomButtonsSensitivity();
     }
 
     _updateZoomButtonsSensitivity() {
-        let zoomLevel = this._mapView.view.zoom_level;
-        let maxZoomLevel = this._mapView.view.max_zoom_level;
-        let minZoomLevel = this._mapView.view.min_zoom_level;
+        let zoomLevel = this._mapView.map.viewport.zoom_level;
+        let maxZoomLevel = this._mapView.map.viewport.max_zoom_level;
+        let minZoomLevel = this._mapView.map.viewport.min_zoom_level;
         let zoomInAction = this.lookup_action("zoom-in");
         let zoomOutAction = this.lookup_action("zoom-out");
 
@@ -353,53 +301,33 @@ var MainWindow = GObject.registerClass({
     }
 
     _updateLocationSensitivity() {
-        let sensitive = (Application.geoclue.state !== Geoclue.State.INITIAL &&
-                         (this.application.connected ||
-                          this.application.local_tile_path));
+        let sensitive = Application.geoclue.state !== Geoclue.State.INITIAL;
 
         this.lookup_action("goto-user-location").set_enabled(sensitive);
     }
 
     _initHeaderbar() {
-        this._headerBarLeft = new HeaderBar.HeaderBarLeft({
-            mapView: this._mapView,
-            application: this.application
-        });
+        this._headerBarLeft = new HeaderBarLeft({ mapView: this._mapView });
         this._headerBar.pack_start(this._headerBarLeft);
 
-        this._headerBarRight = new HeaderBar.HeaderBarRight({
-            mapView: this._mapView,
-            application: this.application
-        });
+        this._headerBarRight = new HeaderBarRight({ mapView: this._mapView });
         this._headerBar.pack_end(this._headerBarRight);
 
         this._placeEntry = this._createPlaceEntry();
-        this._headerBar.custom_title = this._placeEntry;
+        this._headerBar.title_widget = this._placeEntry;
 
         Application.geoclue.connect('notify::state',
                                     this._updateLocationSensitivity.bind(this));
-        this.application.connect('notify::connected', () => {
-            let app = this.application;
-
-            this._updateLocationSensitivity();
-            this._placeEntry.sensitive = app.connected;
-        });
 
         // action bar, for when the window is too narrow for the full headerbar
-        this._actionBarLeft =  new HeaderBar.HeaderBarLeft({
-            mapView: this._mapView,
-            application: this.application
-        })
+        this._actionBarLeft =  new HeaderBarLeft({ mapView: this._mapView });
         this._actionBar.pack_start(this._actionBarLeft);
 
-        this._actionBarRight = new HeaderBar.HeaderBarRight({
-            mapView: this._mapView,
-            application: this.application
-        })
+        this._actionBarRight = new HeaderBarRight({ mapView: this._mapView });
         this._actionBar.pack_end(this._actionBarRight);
 
-        this.connect('size-allocate', () => {
-            let [width, height] = this.get_size();
+        this.connect('notify::default-width', () => {
+            let width = this.default_width;
             if (width < _ADAPTIVE_VIEW_WIDTH) {
                 this.application.adaptive_mode = true;
                 this._headerBarLeft.hide();
@@ -419,18 +347,12 @@ var MainWindow = GObject.registerClass({
     }
 
     _saveWindowGeometry() {
-        let window = this.get_window();
-        let state = window.get_state();
-
-        if (state & Gdk.WindowState.MAXIMIZED)
+        if (this.maximized)
             return;
 
         // GLib.Variant.new() can handle arrays just fine
-        let size = this.get_size();
-        Application.settings.set('window-size', size);
-
-        let position = this.get_position();
-        Application.settings.set('window-position', position);
+        Application.settings.set('window-size',
+                                 [this.default_width, this.default_height]);
     }
 
     _restoreWindowGeometry() {
@@ -440,45 +362,31 @@ var MainWindow = GObject.registerClass({
             this.set_default_size(width, height);
         }
 
-        let position = Application.settings.get('window-position');
-        if (position.length === 2) {
-            let [x, y] = position;
-
-            this.move(x, y);
-        }
-
         if (Application.settings.get('window-maximized'))
             this.maximize();
     }
 
-    _onConfigureEvent(widget, event) {
+    _onSizeChanged() {
         if (this._configureId !== 0) {
-            Mainloop.source_remove(this._configureId);
+            GLib.source_remove(this._configureId);
             this._configureId = 0;
         }
 
-        this._configureId = Mainloop.timeout_add(_CONFIGURE_ID_TIMEOUT, () => {
+        this._configureId = GLib.timeout_add(null, _CONFIGURE_ID_TIMEOUT, () => {
             this._saveWindowGeometry();
             this._configureId = 0;
             return false;
         });
     }
 
-    _onWindowStateEvent(widget, event) {
-        let window = widget.get_window();
-        let state = window.get_state();
-
-        if (state & Gdk.WindowState.FULLSCREEN)
-            return;
-
-        let maximized = (state & Gdk.WindowState.MAXIMIZED);
-        Application.settings.set('window-maximized', maximized);
+    _onMaximizedChanged() {
+        Application.settings.set('window-maximized', this.maximized);
     }
 
     _quit() {
         // remove configure event handler if still there
         if (this._configureId !== 0) {
-            Mainloop.source_remove(this._configureId);
+            GLib.source_remove(this._configureId);
             this._configureId = 0;
         }
 
@@ -504,13 +412,13 @@ var MainWindow = GObject.registerClass({
                 break;
 
             case Geoclue.State.DENIED:
-                let dialog = new LocationServiceDialog.LocationServiceDialog({
+                let dialog = new LocationServiceDialog({
                     visible: true,
                     transient_for: this,
                     modal: true });
 
                 dialog.connect('response', () => dialog.destroy());
-                dialog.show_all();
+                dialog.present();
                 break;
 
             default:
@@ -520,41 +428,32 @@ var MainWindow = GObject.registerClass({
         });
     }
 
-    _activateExport() {
-        let view = this._mapView.view;
-        let surface = view.to_surface(true);
-        let bbox = view.get_bounding_box();
-        let [latitude, longitude] = bbox.get_center();
+    _onExportActivated() {
+        let {x, y, width, height} = this._mapView.get_allocation();
+        let paintable = new Gtk.WidgetPaintable({ widget: this._mapView });
+        let [latitude, longitude] =
+            this._mapView.map.viewport.widget_coords_to_location(this._mapView.map,
+                                                                 width / 2,
+                                                                 height / 2);
 
-        let dialog = new ExportViewDialog.ExportViewDialog({
+        let dialog = new ExportViewDialog({
             transient_for: this,
             modal: true,
-            surface: surface,
+            paintable: paintable,
             latitude: latitude,
             longitude: longitude,
+            width: width,
+            height: height,
             mapView: this._mapView
         });
 
         dialog.connect('response', () => dialog.destroy());
-        dialog.show_all();
-    }
-
-    _onExportActivated() {
-        if (this._mapView.view.state === Champlain.State.DONE) {
-            this._activateExport();
-        } else {
-            let notifyId = this._mapView.view.connect('notify::state', () => {
-                if (this._mapView.view.state === Champlain.State.DONE) {
-                    this._mapView.view.disconnect(notifyId);
-                    this._activateExport();
-                }
-            });
-        }
+        dialog.show();
     }
 
     _printRouteActivate() {
         if (this._mapView.routeShowing) {
-            let operation = new PrintOperation.PrintOperation({ mainWindow: this });
+            let operation = new PrintOperation({ mainWindow: this });
         }
     }
 
@@ -587,48 +486,36 @@ var MainWindow = GObject.registerClass({
     }
 
     _onAboutActivate() {
-        let aboutDialog = new Gtk.AboutDialog({
-            artists: [ 'Jakub Steiner <jimmac@gmail.com>',
-                       'Andreas Nilsson <nisses.mail@home.se>' ],
-            authors: [ 'Zeeshan Ali (Khattak) <zeeshanak@gnome.org>',
-                       'Mattias Bengtsson <mattias.jc.bengtsson@gmail.com>',
-                       'Jonas Danielsson <jonas@threetimestwo.org>',
-                       'Marcus Lundblad <ml@update.uu.se>'],
+        let about = new Adw.AboutWindow({
+            designers: [ 'Jakub Steiner <jimmac@gmail.com>',
+                         'Andreas Nilsson <nisses.mail@home.se>' ],
+            developers: [ 'Zeeshan Ali (Khattak) <zeeshanak@gnome.org>',
+                          'Mattias Bengtsson <mattias.jc.bengtsson@gmail.com>',
+                          'Jonas Danielsson <jonas@threetimestwo.org>',
+                          'Marcus Lundblad <ml@dfupdate.se>'],
+            developer_name: _("The GNOME Project"),
             translator_credits: _("translator-credits"),
             /* Translators: This is the program name. */
-            program_name: _("Maps"),
-            comments: _("A map application for GNOME"),
+            application_name: _("Maps"),
+            application_icon: pkg.name,
+            copyright: _("Copyright © 2011 – 2022 Red Hat, Inc. and The GNOME Maps authors"),
             license_type: Gtk.License.GPL_2_0,
-            logo_icon_name: pkg.name,
             version: pkg.version,
             website: 'https://live.gnome.org/Apps/Maps',
-            wrap_license: true,
-
-            modal: true,
+            issue_url: 'https://gitlab.gnome.org/GNOME/gnome-maps/-/issues/new',
             transient_for: this
         });
 
-        let copyright = _("Copyright © 2011 – 2021 Red Hat, Inc. and The GNOME Maps authors");
-        let attribution = this._getAttribution();
+        this._addAttribution(about);
 
-        copyright += '\n' + attribution;
-
-        /* HACK: we need to poke into gtkaboutdialog internals
-         * to set the copyright with markup like attribution requires
-         */
-
-        let copyrightLabel = aboutDialog.get_template_child(Gtk.AboutDialog, 'copyright_label');
-        copyrightLabel.set_markup('<span size="small">' + copyright + '</span>');
-        copyrightLabel.show();
-
-        aboutDialog.show();
-        aboutDialog.connect('response', () => aboutDialog.destroy());
+        about.present();
     }
 
-    _getAttribution() {
+    _addAttribution(about) {
         let tileProviderInfo = Service.getService().tileProviderInfo;
         let photonGeocode = Service.getService().photonGeocode;
         let attribution = _("Map data by %s and contributors").format('<a href="https://www.openstreetmap.org">OpenStreetMap</a>');
+        about.add_legal_section(_("Map Data Provider"), null, Gtk.License.CUSTOM, attribution);
 
         if (tileProviderInfo) {
             let tileProviderString;
@@ -638,13 +525,18 @@ var MainWindow = GObject.registerClass({
             } else {
                 tileProviderString = tileProviderInfo.name;
             }
-            attribution += '\n';
-            /* Translators: this is an attribution string giving credit to the
-             * tile provider where the %s placeholder is replaced by either
-             * the bare name of the tile provider, or a linkified URL if one
-             * is available
-             */
-            attribution += _("Map tiles provided by %s").format(tileProviderString);
+
+            about.add_legal_section(
+                _("Map Tile Provider"),
+                null,
+                Gtk.License.CUSTOM,
+                /* Translators: this is an attribution string giving credit to the
+                * tile provider where the %s placeholder is replaced by either
+                * the bare name of the tile provider, or a linkified URL if one
+                * is available
+                */
+                _("Map tiles provided by %s").format(tileProviderString)
+            );
         }
 
         let provider = GeocodeFactory.getGeocoder().attribution;
@@ -663,7 +555,6 @@ var MainWindow = GObject.registerClass({
         let geocoderLink =
             '<a href="%s">%s</a>'.format(geocoderUrl, geocoderName);
 
-        attribution += '\n';
         /* Translators: this is an attribution string giving credit to the
          * search provider where the first %s placeholder is replaced by either
          * the bare name of the geocoder provider, or a linkified URL if one
@@ -673,8 +564,12 @@ var MainWindow = GObject.registerClass({
          * (i.e. "%2$s ... %1$s ..." for positioning the project URL
          * before the provider).
          */
-        attribution += _("Search provided by %s using %s").
-            format(providerString, geocoderLink);
+        about.add_legal_section(
+            _("Search Provider"),
+            null,
+            Gtk.License.CUSTOM,
+            _("Search provided by %s using %s").format(providerString, geocoderLink)
+        );
 
         return attribution;
     }
@@ -694,4 +589,18 @@ var MainWindow = GObject.registerClass({
         });
         this._fileChooser.show();
     }
-});
+
+    _showMainMenu() {
+        this._mainMenuButton.activate();
+    }
+}
+
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/main-window.ui',
+    InternalChildren: [ 'headerBar',
+                        'mainMenuButton',
+                        'grid',
+                        'actionBar',
+                        'actionBarRevealer',
+                        'placeBarContainer']
+}, MainWindow);
