@@ -19,13 +19,51 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const OSMTypeListRow = imports.osmTypeListRow;
-const SearchPopover = imports.searchPopover;
+import {OSMTypeListRow} from './osmTypeListRow.js';
+import {SearchPopover} from './searchPopover.js';
 
-var OSMTypePopover = GObject.registerClass({
+export class OSMTypePopover extends SearchPopover {
+
+    constructor(props) {
+        super(props);
+
+        this._list.connect('row-activated', (list, row) => {
+            if (row)
+                this.emit('selected', row.key, row.value, row.title);
+        });
+    }
+
+    showMatches(matches) {
+        let rows = [];
+
+        for (let row of this._list) {
+            rows.push(row);
+        }
+        for (let row of rows) {
+            this._list.remove(row);
+        }
+
+        matches.forEach((type) => this._addRow(type));
+
+        let {x, y, width, height} = this.get_parent().get_allocation();
+
+        // Magic number to make the alignment pixel perfect.
+        this.width_request = width + 20;
+
+        this.popup();
+    }
+
+    _addRow(type) {
+        let row = new OSMTypeListRow({ type: type, can_focus: true });
+
+        this._list.insert(row, -1);
+    }
+}
+
+GObject.registerClass({
     InternalChildren: ['list'],
     Template: 'resource:///org/gnome/Maps/ui/osm-type-popover.ui',
     Signals : {
@@ -35,27 +73,4 @@ var OSMTypePopover = GObject.registerClass({
                                       GObject.TYPE_STRING,
                                       GObject.TYPE_STRING ] }
     }
-}, class OSMTypePopover extends SearchPopover.SearchPopover {
-
-    _init(props) {
-        super._init(props);
-
-        this._list.connect('row-activated', (list, row) => {
-            if (row)
-                this.emit('selected', row.key, row.value, row.title);
-        });
-    }
-
-    showMatches(matches) {
-        this._list.foreach((row) => this._list.remove(row));
-
-        matches.forEach((type) => this._addRow(type));
-        this.show();
-    }
-
-    _addRow(type) {
-        let row = new OSMTypeListRow.OSMTypeListRow({ type: type,
-                                                      can_focus: true });
-        this._list.insert(row, -1);
-    }
-});
+}, OSMTypePopover);
