@@ -19,55 +19,46 @@
  * Author: James Westman <james@flyingpimonster.net>
  */
 
-const Clutter = imports.gi.Clutter;
-const Gdk = imports.gi.Gdk;
-const Geocode = imports.gi.GeocodeGlib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+import Gdk from 'gi://Gdk';
+import GeocodeGlib from 'gi://GeocodeGlib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const Application = imports.application;
-const ContactPlace = imports.contactPlace;
-const PlaceButtons = imports.placeButtons;
-const PlaceDialog = imports.placeDialog;
-const PlaceFormatter = imports.placeFormatter;
-const PlaceView = imports.placeView;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import {PlaceButtons} from './placeButtons.js';
+import {PlaceDialog} from './placeDialog.js';
+import {PlaceFormatter} from './placeFormatter.js';
+import {PlaceView} from './placeView.js';
+import * as Utils from './utils.js';
 
-var PlaceBar = GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/place-bar.ui',
-    InternalChildren: [ 'actionbar',
-                        'altSendToButton',
-                        'box',
-                        'eventbox',
-                        'contactAvatar',
-                        'title' ],
-    Properties: {
-        'place': GObject.ParamSpec.object('place',
-                                          'Place',
-                                          'The place to show information about',
-                                          GObject.ParamFlags.READABLE |
-                                          GObject.ParamFlags.WRITABLE,
-                                          Geocode.Place)
-    },
-}, class PlaceBar extends Gtk.Revealer {
-    _init(params) {
-        this._mapView = params.mapView;
+export class PlaceBar extends Gtk.Revealer {
+    constructor(params) {
+        let mapView = params.mapView;
         delete params.mapView;
 
-        super._init(params);
+        let mainWindow = params.mainWindow;
+        delete params.mainWindow;
 
-        this._buttons = new PlaceButtons.PlaceButtons({ mapView: this._mapView });
+        super(params);
+
+        this._mapView = mapView;
+        this._mainWindow = mainWindow;
+        this._buttons = new PlaceButtons({ mapView: this._mapView });
         this._buttons.initSendToButton(this._altSendToButton);
         this._buttons.connect('place-edited', this._onPlaceEdited.bind(this));
-        this._box.add(this._buttons);
+        this._box.append(this._buttons);
 
-        this._multipress = new Gtk.GestureMultiPress({ widget: this._eventbox });
-        this._multipress.connect('released', this._onEventBoxClicked.bind(this));
+        this._click = new Gtk.GestureClick();
+        this._box.add_controller(this._click);
+        this._click.connect('released', this._onBoxClicked.bind(this));
 
         Application.application.connect('notify::adaptive-mode', this._updateVisibility.bind(this));
         this.connect('notify::place', this._updatePlace.bind(this));
 
-        this._mapView.view.connect('touch-event', this._onMapClickEvent.bind(this));
+        this._mapClick = new Gtk.GestureSingle();
+        this._mapView.add_controller(this._mapClick);
+
+        this._mapClick.connect('begin', this._onMapClickEvent.bind(this));
     }
 
     _updatePlace() {
@@ -82,21 +73,9 @@ var PlaceBar = GObject.registerClass({
             return;
         }
 
-        let formatter = new PlaceFormatter.PlaceFormatter(this.place);
+        let formatter = new PlaceFormatter(this.place);
         this._title.label = formatter.title;
 
-        if (this.place instanceof ContactPlace.ContactPlace) {
-            this._contactAvatar.visible = true;
-            this._contactAvatar.text = formatter.title;
-
-            this._contactAvatar.set_image_load_func(null);
-            Utils.load_icon(this.place.icon, 32, (pixbuf) => {
-                this._contactAvatar.set_image_load_func((size) => Utils.loadAvatar(pixbuf, size));
-            });
-        } else {
-            this._contactAvatar.visible = false;
-        }
-
         this._buttons.place = this.place;
 
         this._altSendToButton.visible = this.place.isCurrentLocation;
@@ -111,23 +90,23 @@ var PlaceBar = GObject.registerClass({
         }
     }
 
-    _onEventBoxClicked() {
+    _onBoxClicked() {
         if (this.place.isCurrentLocation) {
             if (this._currentLocationView) {
                 this._box.remove(this._currentLocationView);
                 delete this._currentLocationView;
             } else {
-                this._currentLocationView = new PlaceView.PlaceView({ place: this.place,
-                                                                      mapView: this._mapView,
-                                                                      inlineMode: true,
-                                                                      visible: true });
-                this._box.add(this._currentLocationView);
+                this._currentLocationView = new PlaceView({ place: this.place,
+                                                            mapView: this._mapView,
+                                                            inlineMode: true,
+                                                            visible: true });
+                this._box.append(this._currentLocationView);
             }
         } else {
-            this._dialog = new PlaceDialog.PlaceDialog ({ transient_for: this.get_toplevel(),
-                                                        modal: true,
-                                                        mapView: this._mapView,
-                                                        place: this.place });
+            this._dialog = new PlaceDialog ({ transient_for: this._mainWindow,
+                                              modal: true,
+                                              mapView: this._mapView,
+                                              place: this.place });
             this._dialog.connect('response', () => {
                 this._dialog.destroy();
                 delete this._dialog;
@@ -141,20 +120,24 @@ var PlaceBar = GObject.registerClass({
     }
 
     _onMapClickEvent(view, event) {
-        switch (event.type()) {
-            case Clutter.EventType.TOUCH_BEGIN:
-                this._tapped = true;
-                break;
-            case Clutter.EventType.TOUCH_UPDATE:
-                this._tapped = false;
-            case Clutter.EventType.TOUCH_END:
-            case Clutter.EventType.TOUCH_CANCEL:
-                if (this._tapped) {
-                    Application.application.selected_place = null;
-                }
-                break;
-        }
-
-        return Clutter.EVENT_PROPAGATE;
+       Application.application.selected_place = null;
+       this.reveal_child = false;
     }
-});
+}
+
+GObject.registerClass({
+    Template: 'resource:///org/gnome/Maps/ui/place-bar.ui',
+    InternalChildren: [ 'actionbar',
+                        'altSendToButton',
+                        'box',
+                        'title' ],
+    Properties: {
+        'place': GObject.ParamSpec.object('place',
+                                          'Place',
+                                          'The place to show information about',
+                                          GObject.ParamFlags.READABLE |
+                                          GObject.ParamFlags.WRITABLE,
+                                          GeocodeGlib.Place)
+    },
+}, PlaceBar);
+
