@@ -20,22 +20,24 @@
  *         Mattias Bengtsson <mattias.jc.bengtsson@gmail.com>
  */
 
-const _ = imports.gettext.gettext;
+import gettext from 'gettext';
 
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Geocode = imports.gi.GeocodeGlib;
-const Gio = imports.gi.Gio;
-const Gtk = imports.gi.Gtk;
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import GeocodeGlib from 'gi://GeocodeGlib';
+import Gio from 'gi://Gio';
+import Gtk from 'gi://Gtk';
 
-const Application = imports.application;
-const GeocodeFactory = imports.geocode;
-const Location = imports.location;
-const Place = imports.place;
-const PlaceStore = imports.placeStore;
-const PlacePopover = imports.placePopover;
-const URIS = imports.uris;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import * as GeocodeFactory from './geocode.js';
+import {Location} from './location.js';
+import {Place} from './place.js';
+import {PlaceStore} from './placeStore.js';
+import {PlacePopover} from './placePopover.js';
+import * as URIS from './uris.js';
+import * as Utils from './utils.js';
+
+const _ = gettext.gettext;
 
 // minimum number of characters to start completion
 const MIN_CHARS_COMPLETION = 3;
@@ -43,16 +45,7 @@ const MIN_CHARS_COMPLETION = 3;
 // pattern matching CJK ideographic characters
 const IDEOGRAPH_PATTERN = /[\u3300-\u9fff]/
 
-var PlaceEntry = GObject.registerClass({
-    Properties: {
-        'place': GObject.ParamSpec.object('place',
-                                          'Place',
-                                          'The selected place',
-                                          GObject.ParamFlags.READABLE |
-                                          GObject.ParamFlags.WRITABLE,
-                                          Geocode.Place)
-    }
-}, class PlaceEntry extends Gtk.SearchEntry {
+export class PlaceEntry extends Gtk.SearchEntry {
 
     set place(p) {
         if (!this._place && !p)
@@ -75,9 +68,11 @@ var PlaceEntry = GObject.registerClass({
             this._placeText = '';
         }
 
-        this.text = this._placeText;
+        if (this.text !== this._placeText)
+            this._setTextWithoutTriggerSearch(this._placeText);
 
         this._place = p;
+
         this.notify('place');
     }
 
@@ -89,37 +84,38 @@ var PlaceEntry = GObject.registerClass({
         return this._popover;
     }
 
-    _init(props) {
-        let numVisible = props.num_visible || 6;
-        delete props.num_visible;
-        this._mapView = props.mapView;
+    constructor(props) {
+        let mapView = props.mapView;
         delete props.mapView;
 
-        if (!props.loupe)
-            props.primary_icon_name = null;
-        delete props.loupe;
-
         let maxChars = props.maxChars;
         delete props.maxChars;
 
-        this._matchRoute = props.matchRoute || false;
+        let matchRoute = props.matchRoute ?? false;
         delete props.matchRoute;
 
-        super._init(props);
+        super(props);
 
+        this._mapView = mapView;
+        this._matchRoute = matchRoute;
         this._filter = new Gtk.TreeModelFilter({ child_model: Application.placeStore });
         this._filter.set_visible_func(this._completionVisibleFunc.bind(this));
 
-        this._popover = this._createPopover(numVisible, maxChars);
+        this._popover = this._createPopover(maxChars);
 
         this.connect('search-changed', this._onSearchChanged.bind(this));
 
         this._cache = {};
 
         // clear cache when view moves, as result are location-dependent
-        this._mapView.view.connect('notify::latitude', () => this._cache = {});
+        this._mapView.map.viewport.connect('notify::latitude', () => this._cache = {});
         // clear cache when zoom level changes, to allow limiting location bias
-        this._mapView.view.connect('notify::zoom-level', () => this._cache =  {});
+        this._mapView.map.viewport.connect('notify::zoom-level', () => this._cache =  {});
+    }
+
+    _setTextWithoutTriggerSearch(text) {
+        this._setText = text;
+        this.text = text;
     }
 
     _onSearchChanged() {
@@ -130,6 +126,10 @@ var PlaceEntry = GObject.registerClass({
         if (this._cancellable)
             return;
 
+        // don't trigger a search when setting explicit text (such as reordering points)
+        if (this.text === this._setText)
+            return;
+
         /* start search if more than the threshold number of characters have
          * been entered, or if the first character is in the ideographic CJK
          * block, as for these, shorter strings could be meaningful
@@ -152,7 +152,8 @@ var PlaceEntry = GObject.registerClass({
                 this._doSearch();
             }
         } else {
-            this._popover.hide();
+            this._popover.popdown();
+            this.grab_focus();
             if (this.text.length === 0)
                 this.place = null;
             this._previousSearch = null;
@@ -167,32 +168,30 @@ var PlaceEntry = GObject.registerClass({
                 placeA.location.longitude === placeB.location.longitude);
     }
 
-    _createPopover(numVisible, maxChars) {
-        let popover = new PlacePopover.PlacePopover({ num_visible:   numVisible,
-                                                      relative_to:   this,
-                                                      maxChars:      maxChars});
+    _createPopover(maxChars) {
+        let popover = new PlacePopover({ entry:         this,
+                                         maxChars:      maxChars });
 
-        this.connect('size-allocate', (widget, allocation) => {
-            // Magic number to make the alignment pixel perfect.
-            let width_request = allocation.width + 20;
-            // set at least 320 px width to avoid too narrow in the sidebar
-            popover.width_request = Math.max(width_request, 320);
-        });
+        popover.set_parent(this);
+        this.set_key_capture_widget(popover);
 
         popover.connect('selected', (widget, place) => {
             this.place = place;
-            popover.hide();
+            popover.popdown();
         });
 
         return popover;
     }
 
+    _onKeyPressed(controller, keyval, keycode, state) {
+        return true;
+    }
+
     _completionVisibleFunc(model, iter) {
         let place = model.get_value(iter, PlaceStore.Columns.PLACE);
         let type = model.get_value(iter, PlaceStore.Columns.TYPE);
 
-        if (type !== PlaceStore.PlaceType.CONTACT &&
-            type !== PlaceStore.PlaceType.RECENT_ROUTE ||
+        if (type !== PlaceStore.PlaceType.RECENT_ROUTE ||
             (!this._matchRoute && type === PlaceStore.PlaceType.RECENT_ROUTE))
             return false;
 
@@ -215,11 +214,11 @@ var PlaceEntry = GObject.registerClass({
         let parsed = false;
 
         if (this.text.startsWith('geo:')) {
-            let location = new Geocode.Location();
+            let location = new GeocodeGlib.Location();
 
             try {
                 location.set_from_uri(this.text);
-                this.place = new Place.Place({ location: location });
+                this.place = new Place({ location: location });
             } catch(e) {
                 let msg = _("Failed to parse Geo URI");
                 Utils.showDialog(msg, Gtk.MessageType.ERROR, this.get_toplevel());
@@ -241,7 +240,7 @@ var PlaceEntry = GObject.registerClass({
             parsed = true;
         }
 
-        let parsedLocation = Place.Place.parseCoordinates(this.text);
+        let parsedLocation = Place.parseCoordinates(this.text);
         if (parsedLocation) {
             /* if the place was a parsed OSM coordinate URL, it will have
              * gotten re-written as bare coordinates and trigger a search-changed,
@@ -250,7 +249,7 @@ var PlaceEntry = GObject.registerClass({
              */
             if (!this.place ||
                 !this._roundedLocEquals(parsedLocation, this.place.location))
-                this.place = new Place.Place({ location: parsedLocation });
+                this.place = new Place({ location: parsedLocation });
             parsed = true;
         }
 
@@ -285,17 +284,9 @@ var PlaceEntry = GObject.registerClass({
         this._cancellable = new Gio.Cancellable();
         this._previousSearch = this.text;
 
-        /* as a stop-gap solution for the location bias tuning issues
-         * in Photon (https://github.com/komoot/photon/issues/600),
-         * for now search "globally" (e.g. without location bias) for
-         * zoom levels above 17, to still allow focused search nearby
-         */
-        let lat = this._mapView.view.zoom_level > 17 ?
-                  this._mapView.view.latitude : null;
-        let lon = this._mapView.view.zoom_level > 17 ?
-                  this._mapView.view.longitude : null;
-
-        GeocodeFactory.getGeocoder().search(this.text, lat, lon,
+        GeocodeFactory.getGeocoder().search(this.text,
+                                            this._mapView.map.viewport.latitude,
+                                            this._mapView.map.viewport.longitude,
                                             this._cancellable,
                                             (places, error) => {
             this._cancellable = null;
@@ -361,4 +352,15 @@ var PlaceEntry = GObject.registerClass({
         this._popover.updateResult(completedPlaces, searchText);
         this._popover.showResult();
     }
-});
+}
+
+GObject.registerClass({
+    Properties: {
+        'place': GObject.ParamSpec.object('place',
+                                          'Place',
+                                          'The selected place',
+                                          GObject.ParamFlags.READABLE |
+                                          GObject.ParamFlags.WRITABLE,
+                                          GeocodeGlib.Place)
+    }
+}, PlaceEntry);
