@@ -17,72 +17,56 @@
  * Author: Jonas Danielsson <jonas@threetimestwo.org>
  */
 
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
 
-const Application = imports.application;
-const PlaceListRow = imports.placeListRow;
-const PlaceStore = imports.placeStore;
-const SearchPopover = imports.searchPopover;
+import {Application} from './application.js';
+import {PlaceListRow} from './placeListRow.js';
+import {PlaceStore} from './placeStore.js';
+import {SearchPopover} from './searchPopover.js';
 
 const _PLACE_ICON_SIZE = 20;
 
-var PlacePopover = GObject.registerClass({
-    Signals : {
-        'selected' : { param_types: [ GObject.TYPE_OBJECT ] }
-    },
-    Template: 'resource:///org/gnome/Maps/ui/place-popover.ui',
-    InternalChildren: [ 'scrolledWindow',
-                        'stack',
-                        'spinner',
-                        'list',
-                        'noResultsLabel',
-                        'errorLabel' ],
-}, class PlacePopover extends SearchPopover.SearchPopover {
+export class PlacePopover extends SearchPopover {
 
-    _init(props) {
-        let numVisible = props.num_visible;
-        delete props.num_visible;
-
-        this._maxChars = props.maxChars;
+    constructor(props) {
+        let maxChars = props.maxChars;
         delete props.maxChars;
 
-        props.transitions_enabled = false;
-        super._init(props);
+        super(props);
 
-        this._entry = this.relative_to;
+        this._maxChars = maxChars;
 
         this._list.connect('row-activated', (list, row) => {
             if (row)
                 this.emit('selected', row.place);
         });
 
-        this._list.set_header_func((row, before) => {
-            let header = new Gtk.Separator();
-            if (before)
-                row.set_header(header);
-            else
-                row.set_header(null);
-        });
-
-        let rowHeight = PlaceListRow.ROW_HEIGHT;
-        this._scrolledWindow.min_content_height = numVisible * rowHeight + 6;
-
         // This silents warning at Maps exit about this widget being
         // visible but not mapped.
         this.connect('unmap', (popover) => popover.hide());
     }
 
+    _showPopover() {
+        let {x, y, width, height} = this._entry.get_allocation();
+
+        // Magic number to make the alignment pixel perfect.
+        this.width_request = width + 20;
+        this.popup();
+    }
+
     showSpinner() {
         this._spinner.start();
         this._stack.visible_child = this._spinner;
 
         if (!this.visible)
-            this.show();
+            this._showPopover();
+
+        this._numResults = 0;
     }
 
     showResult() {
-        if (this._spinner.active)
+        if (this._spinner.spinning)
             this._spinner.stop();
 
         this._stack.visible_child = this._scrolledWindow;
@@ -92,21 +76,23 @@ var PlacePopover = GObject.registerClass({
             this._list.select_row(row);
 
         if (!this.visible)
-            this.show();
+            this._showPopover();
     }
 
     showNoResult() {
-        if (this._spinner.active)
+        if (this._spinner.spinning)
             this._spinner.stop();
 
         this._stack.visible_child = this._noResultsLabel;
+        this._numResults = 0;
     }
 
     showError() {
-        if (this._spinner.active)
+        if (this._spinner.spinning)
             this._spinner.stop();
 
         this._stack.visible_child = this._errorLabel;
+        this._numResults = 0;
     }
 
     updateResult(places, searchString) {
@@ -124,6 +110,8 @@ var PlacePopover = GObject.registerClass({
             i++;
         });
 
+        this._numResults = i;
+
         // remove remaining rows
         let row = this._list.get_row_at_index(i);
 
@@ -134,10 +122,23 @@ var PlacePopover = GObject.registerClass({
     }
 
     _addRow(place, type, searchString) {
-        let row = new PlaceListRow.PlaceListRow({ place: place,
-                                                  searchString: searchString,
-                                                  type: type,
-                                                  can_focus: true });
+        let row = new PlaceListRow({ place:        place,
+                                     searchString: searchString,
+                                     type:         type,
+                                     can_focus:    true });
         this._list.insert(row, -1);
     }
-});
+}
+
+GObject.registerClass({
+    Signals : {
+        'selected' : { param_types: [ GObject.TYPE_OBJECT ] }
+    },
+    Template: 'resource:///org/gnome/Maps/ui/place-popover.ui',
+    InternalChildren: [ 'scrolledWindow',
+                        'stack',
+                        'spinner',
+                        'list',
+                        'noResultsLabel',
+                        'errorLabel' ],
+}, PlacePopover);
