@@ -19,26 +19,25 @@
  * Author: Damián Nohales <damiannohales@gmail.com>
  */
 
-const Geocode = imports.gi.GeocodeGlib;
-const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
-const Gtk = imports.gi.Gtk;
-const Pango = imports.gi.Pango;
+import GeocodeGlib from 'gi://GeocodeGlib';
+import GLib from 'gi://GLib';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import Pango from 'gi://Pango';
 
 const Format = imports.format;
 
-const Application = imports.application;
-const ContactPlace = imports.contactPlace;
-const Overpass = imports.overpass;
-const Place = imports.place;
-const PlaceIcons = imports.placeIcons;
-const PlaceViewImage = imports.placeViewImage;
-const PlaceButtons = imports.placeButtons;
-const PlaceFormatter = imports.placeFormatter;
-const PlaceStore = imports.placeStore;
-const Translations = imports.translations;
-const Utils = imports.utils;
-const Wikipedia = imports.wikipedia;
+import {Application} from './application.js';
+import {Overpass} from './overpass.js';
+import {Place} from './place.js';
+import * as PlaceIcons from './placeIcons.js';
+import {PlaceViewImage} from './placeViewImage.js';
+import {PlaceButtons} from './placeButtons.js';
+import {PlaceFormatter} from './placeFormatter.js';
+import {PlaceStore} from './placeStore.js';
+import * as Translations from './translations.js';
+import * as Utils from './utils.js';
+import * as Wikipedia from './wikipedia.js';
 
 // maximum dimension of thumbnails to fetch from Wikipedia
 const THUMBNAIL_FETCH_SIZE = 360;
@@ -46,19 +45,10 @@ const THUMBNAIL_FETCH_SIZE = 360;
 // Unicode left-to-right marker
 const LRM = '\u200E';
 
-var PlaceView = GObject.registerClass({
-    Properties: {
-        'overpass-place': GObject.ParamSpec.object('overpass-place',
-                                                   'Overpass Place',
-                                                   'The place as filled in by Overpass',
-                                                   GObject.ParamFlags.READABLE |
-                                                   GObject.ParamFlags.WRITABLE,
-                                                   Geocode.Place)
-    }
-}, class PlaceView extends Gtk.Box {
+export class PlaceView extends Gtk.Box {
 
-    _init(params) {
-        this._place = params.place;
+    constructor(params) {
+        let place = params.place;
         delete params.place;
 
         let mapView = params.mapView;
@@ -66,10 +56,13 @@ var PlaceView = GObject.registerClass({
 
         /* This mode is used in PlaceBar for inline current location details.
            It hides the title box and decreases the start margin on the rows. */
-        this._inlineMode = !!params.inlineMode;
+        let inlineMode = !!params.inlineMode;
         delete params.inlineMode;
 
-        super._init(params);
+        super(params);
+
+        this._place = place;
+        this._inlineMode = inlineMode;
 
         let ui = Utils.getUIObject('place-view', [ 'bubble-main-box',
                                                    'bubble-spinner',
@@ -77,7 +70,6 @@ var PlaceView = GObject.registerClass({
                                                    'thumbnail-separator',
                                                    'label-title',
                                                    'native-name',
-                                                   'contact-avatar',
                                                    'address-label',
                                                    'bubble-main-stack',
                                                    'bubble-content-area',
@@ -92,15 +84,14 @@ var PlaceView = GObject.registerClass({
         this._mainStack = ui.bubbleMainStack;
         this._spinner = ui.bubbleSpinner;
         this._mainBox = ui.bubbleMainBox;
-        this._contactAvatar = ui.contactAvatar;
         this._addressLabel = ui.addressLabel;
 
-        this.add(this._mainStack);
+        this.append(this._mainStack);
 
-        let placeButtons = new PlaceButtons.PlaceButtons({ place: this._place,
-                                                           mapView: mapView });
+        let placeButtons = new PlaceButtons({ place: this._place,
+                                              mapView: mapView });
         placeButtons.connect('place-edited', this._onPlaceEdited.bind(this));
-        ui.placeButtons.add(placeButtons);
+        ui.placeButtons.append(placeButtons);
 
         if (this.place.isCurrentLocation) {
             /* Current Location bubbles have a slightly different layout, to
@@ -119,14 +110,6 @@ var PlaceView = GObject.registerClass({
             ui.titleBox.spacing = 18;
         }
 
-        /* Set up contact avatar */
-        if (this.place instanceof ContactPlace.ContactPlace) {
-            this._contactAvatar.visible = true;
-            Utils.load_icon(this.place.icon, 32, (pixbuf) => {
-                this._contactAvatar.set_image_load_func((size) => Utils.loadAvatar(pixbuf, size));
-            });
-        }
-
         this.loading = true;
 
         this._placeDetails = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
@@ -137,7 +120,7 @@ var PlaceView = GObject.registerClass({
         if (this.place.isCurrentLocation) {
             this._populate(this.place);
         } else {
-            let overpass = new Overpass.Overpass();
+            let overpass = new Overpass();
 
             /* use a property binding from the Overpass instance to avoid
              * accessing this object after the underlying GObject has
@@ -192,16 +175,16 @@ var PlaceView = GObject.registerClass({
     }
 
     get loading() {
-        return this._spinner.active;
+        return this._spinner.spinning;
     }
     set loading(val) {
         this._mainStack.set_visible_child(val ? this._spinner : this._mainBox);
-        this._spinner.active = val;
+        this._spinner.spinning = val;
     }
 
     updatePlaceDetails() {
         let place = this.place;
-        let formatter = new PlaceFormatter.PlaceFormatter(place);
+        let formatter = new PlaceFormatter(place);
 
         let address = formatter.rows.map((row) => {
             row = row.map(function(prop) {
@@ -217,7 +200,6 @@ var PlaceView = GObject.registerClass({
         }
 
         this._title.label = formatter.title;
-        this._contactAvatar.text = formatter.title;
 
         /* hide native name by default, so that it is only shown when it
          * should, in case it changed when re-applying changes from Overpass.
@@ -253,7 +235,7 @@ var PlaceView = GObject.registerClass({
         let lang = Wikipedia.getLanguage(wiki);
         let article = Wikipedia.getArticle(wiki);
 
-        return Format.vprintf('https://%s.wikipedia.org/wiki/%s', [ lang, article ]);
+        return `https://${lang}.wikipedia.org/wiki/${article}`;
     }
 
     _createContent(place) {
@@ -298,7 +280,7 @@ var PlaceView = GObject.registerClass({
             if (Utils.uriSchemeSupported('tel')) {
                 /* RFC3966 only allows "-", '.", "(", and ")" as visual
                  * separator characters in a global phone number, no space */
-                phone.linkUrl = 'tel:%s'.format(place.phone.replace(/\s+/g, ''));
+                phone.linkUrl = `tel:${place.phone.replace(/\s+/g, '')}`;
             }
 
             content.push(phone);
@@ -308,7 +290,7 @@ var PlaceView = GObject.registerClass({
             content.push({ label: _("E-mail"),
                            icon: 'mail-unread-symbolic',
                            info: GLib.markup_escape_text(place.email, -1),
-                           linkUrl: 'mailto:%s'.format(place.email) });
+                           linkUrl: `mailto:${place.email}` });
         }
 
         if (place.isEatingAndDrinking) {
@@ -502,7 +484,7 @@ var PlaceView = GObject.registerClass({
         content.forEach(({ type, label, icon, linkUrl, info, grid }) => {
             let separator = new Gtk.Separator({ visible: true });
             separator.get_style_context().add_class('no-margin-separator');
-            this._placeDetails.add(separator);
+            this._placeDetails.append(separator);
 
             let box = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL,
                                     visible: true,
@@ -519,7 +501,6 @@ var PlaceView = GObject.registerClass({
             if (icon) {
                 let widget = new Gtk.Image({ icon_name: icon,
                                              visible: true,
-                                             xalign: 1,
                                              valign: Gtk.Align.START,
                                              halign: Gtk.Align.END });
 
@@ -527,23 +508,21 @@ var PlaceView = GObject.registerClass({
                     widget.tooltip_markup = label;
                 }
 
-                box.add(widget);
+                box.append(widget);
             } else if (label) {
                 let widget = new Gtk.Label({ label: label.italics(),
                                              visible: true,
                                              use_markup: true,
                                              yalign: 0,
                                              halign: Gtk.Align.END });
-                box.add(widget);
+                box.append(widget);
             }
 
             if (linkUrl) {
                 let uri = GLib.markup_escape_text(linkUrl, -1);
                 /* double-escape the tooltip text, as GTK treats it as markup */
                 let tooltipText = GLib.markup_escape_text(uri, -1);
-                info = '<a href="%s" title="%s">%s</a>'.format(uri,
-                                                               tooltipText,
-                                                               info);
+                info = `<a href="${uri}" title="${tooltipText}">${info}</a>`;
             }
 
             let widget;
@@ -594,8 +573,8 @@ var PlaceView = GObject.registerClass({
                 }
             }
 
-            box.add(widget);
-            this._placeDetails.add(box);
+            box.append(widget);
+            this._placeDetails.append(box);
         });
     }
 
@@ -648,7 +627,15 @@ var PlaceView = GObject.registerClass({
 
     // clear the view widgets to be able to re-populate an updated place
     _clearView() {
-        this._placeDetails.get_children().forEach((child) => this._placeDetails.remove(child));
+        let details = [];
+
+        for (let detail of this._placeDetails) {
+            details.push(detail);
+        }
+
+        for (let detail of details) {
+            this._placeDetails.remove(detail);
+        }
     }
 
     // called when the place's location changes (e.g. for the current location)
@@ -660,4 +647,15 @@ var PlaceView = GObject.registerClass({
     _onPlaceEdited() {
         this._populate(this._place);
     }
-});
+}
+
+GObject.registerClass({
+    Properties: {
+        'overpass-place': GObject.ParamSpec.object('overpass-place',
+                                                   'Overpass Place',
+                                                   'The place as filled in by Overpass',
+                                                   GObject.ParamFlags.READABLE |
+                                                   GObject.ParamFlags.WRITABLE,
+                                                   GeocodeGlib.Place)
+    }
+}, PlaceView);
