@@ -17,31 +17,33 @@
  * Author: Hashem Nasarat <hashem@riseup.net>
  */
 
-const Champlain = imports.gi.Champlain;
-const Gio = imports.gi.Gio;
-const GObject = imports.gi.GObject;
+import Gio from 'gi://Gio';
+import GObject from 'gi://GObject';
+import Gtk from 'gi://Gtk';
+import Shumate from 'gi://Shumate';
 
-const GeoJSONShapeLayer = imports.geoJSONShapeLayer;
-const Utils = imports.utils;
+import {GeoJSONShapeLayer} from './geoJSONShapeLayer.js';
+import * as Utils from './utils.js';
 
-var SUPPORTED_TYPES = [];
+export class ShapeLayer extends GObject.Object {
 
-function newFromFile(file, mapView) {
-    let contentType = Gio.content_type_guess(file.get_uri(), null)[0];
-    for (let layerClass of SUPPORTED_TYPES) {
-        if (layerClass.mimeTypes.indexOf(contentType) > -1) {
-            return layerClass.createInstance({ file: file, mapView: mapView });
+    static mimeTypes = [];
+    static displayName = '';
+
+    static SUPPORTED_TYPES = [];
+
+    static newFromFile(file, mapView) {
+        let contentType = Gio.content_type_guess(file.get_uri(), null)[0];
+        for (let layerClass of ShapeLayer.SUPPORTED_TYPES) {
+            if (layerClass.mimeTypes.indexOf(contentType) > -1) {
+                return layerClass.createInstance({ file: file, mapView: mapView });
+            }
         }
+        return null;
     }
-    return null;
-}
 
-var ShapeLayer = GObject.registerClass({
-    Abstract: true
-}, class ShapeLayer extends GObject.Object {
-
-    _init(params) {
-        super._init();
+    constructor(params) {
+        super();
         this._visible = true;
         this._mapView = params.mapView;
         this.file = params.file;
@@ -52,8 +54,9 @@ var ShapeLayer = GObject.registerClass({
             null
         ).get_attribute_string(Gio.FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME);
 
-        this._markerLayer = new Champlain.MarkerLayer({
-            selection_mode: Champlain.SelectionMode.SINGLE
+        this._markerLayer = new Shumate.MarkerLayer({
+            selection_mode: Gtk.SelectionMode.SINGLE,
+            viewport:       this._mapView.map.viewport
         });
         this._mapSource = null;
     }
@@ -67,13 +70,8 @@ var ShapeLayer = GObject.registerClass({
     }
 
     set visible(v) {
-        if (v && !this._visible) {
-            this._mapView.view.add_overlay_source(this._mapSource, 255);
-            this._markerLayer.show_all_markers();
-        } else if (!v && this._visible) {
-            this._mapView.view.remove_overlay_source(this._mapSource);
-            this._markerLayer.hide_all_markers();
-        }
+        this._overlayLayer.visible = v;
+        this._markerLayer.visible = v;
         this._visible = v;
     }
 
@@ -94,8 +92,8 @@ var ShapeLayer = GObject.registerClass({
                 if (!status)
                     throw new Error(_("failed to load file"));
                 this._parseContent();
-                this._mapView.view.add_layer(this._markerLayer);
-                this._mapView.view.add_overlay_source(this._mapSource, 255);
+                this._mapView.map.add_layer(this._markerLayer);
+                this._mapView.map.add_layer(this._overlayLayer);
             } catch (e) {
                 Utils.debug(e);
                 error = true;
@@ -109,10 +107,12 @@ var ShapeLayer = GObject.registerClass({
     }
 
     unload() {
-        this._mapView.view.remove_layer(this._markerLayer);
-        this._mapView.view.remove_overlay_source(this._mapSource);
+        this._mapView.map.remove_layer(this._markerLayer);
+        this._mapView.map.remove_layer(this._overlayLayer);
     }
-});
+}
+
+GObject.registerClass({
+    Abstract: true
+}, ShapeLayer);
 
-ShapeLayer.mimeTypes = [];
-ShapeLayer.displayName = '';
